@@ -48,7 +48,10 @@ where
                 ResponseType = Self::ResponseType,
                 CursorType = Self::CursorType,
                 ResponseItemType = Self::ResponseItemType,
-            > + 'b + Send + Sync,
+            >
+            + 'b
+            + Send
+            + Sync,
     >
     where
         Self: Send + Clone + Sync + 'b,
